Given a comment id, get the comment from the docx_container

manually construct a sparkle comment for use

comments_df(docx)

get_comment_id(docx, id)

new_sparkle_comment(
  comment_id = -99,
  docx_text = "",
  comment_text = "",
  comment_author = "",
  comment_node = list(as_xml_nodeset("")),
  docx_node = list(as_xml_nodeset("")),
  docx_comment_content_node = list(as_xml_nodeset("")),
  comment_inline = FALSE,
  docx_previous_content_metadata = list(previous_content = FALSE, docx_text = NULL,
    content_hash = NULL, is_inline = NULL)
)

Arguments

docx

a `docx_container`

id

the id of the comment to pull from comment

comment_id

id number of the comment

docx_text

text of the highlighted text that is commented in the docx

comment_text

text of the comment itself

comment_author

Name of the author of the comment

comment_node

list containing the node of the comment from the docx

docx_node

list containing the node that contains comment in the docx

docx_comment_content_node

list containing the nodes that are contained within the comment in the docx

comment_inline

indicator if the commented node is inline or in a new paragraph

docx_previous_content_metadata

List containing metadata from a previously added sparkle