Load a template document with as many Insert paragraphs as there are strings in comment.

load_template_docx(comment, acronyms = NULL)

Arguments

comment

comment

acronyms

acronyms. If set this will add a table in the beginning of the document

Value

a docx_container with the comments