Add styles

style_add(
  docx,
  ...,
  styles,
  replace = TRUE,
  verbose = FALSE,
  error_call = current_env()
)

Arguments

docx

a docx_container object, as created by [load_docx()]

...

variable number of objects that can be converted to styles with [style_make()]

styles

a list of [docx_style] objects, probably made by [style_make()]

replace

if TRUE the style is added even if it already exist in the document

verbose

if TRUE the function is chatty

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.