A style to add to a docx object

style_make(node, error_call = current_env())

Arguments

node

either a string or an xml node, e.g. as created by [polish::as_xml_node()]

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.