Given a comment id, get the comment from the docx_container
manually construct a sparkle comment for use
comments_df(docx)
get_comment_id(docx, id)
new_sparkle_comment(
comment_id = -99,
docx_text = "",
comment_text = "",
comment_author = "",
comment_node = list(as_xml_nodeset("")),
docx_node = list(as_xml_nodeset("")),
docx_comment_content_node = list(as_xml_nodeset("")),
comment_inline = FALSE,
docx_previous_content_metadata = list(previous_content = FALSE, docx_text = NULL,
content_hash = NULL, is_inline = NULL)
)a `docx_container`
the id of the comment to pull from comment
id number of the comment
text of the highlighted text that is commented in the docx
text of the comment itself
Name of the author of the comment
list containing the node of the comment from the docx
list containing the node that contains comment in the docx
list containing the nodes that are contained within the comment in the docx
indicator if the commented node is inline or in a new paragraph
List containing metadata from a previously added sparkle