R/load_template_docx.R
load_template_docx.Rd
Load a template document with as many Insert paragraphs as there are strings in comment.
load_template_docx(comment, acronyms = NULL)
comment
acronyms. If set this will add a table in the beginning of the document
a docx_container with the comments